# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/sindr',
                'doc_host': 'https://$GIT_USER_NAME.github.io',
                'git_url': 'https://github.com/$GIT_USER_NAME/sindr',
                'lib_path': 'sindr'},
  'syms': { 'sindr.core': { 'sindr.core.get_config': ('core.html#get_config', 'sindr/core.py'),
                            'sindr.core.get_samplesheet': ('core.html#get_samplesheet', 'sindr/core.py'),
                            'sindr.core.set_env_variables': ('core.html#set_env_variables', 'sindr/core.py'),
                            'sindr.core.show_project_env_vars': ('core.html#show_project_env_vars', 'sindr/core.py')},
            'sindr.hello_world': { 'sindr.hello_world.cli': ('hello_world.html#cli', 'sindr/hello_world.py'),
                                   'sindr.hello_world.hello_world': ('hello_world.html#hello_world', 'sindr/hello_world.py')},
            'sindr.seq_tools': {},
            'sindr.some_string': {}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_seq_tools.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/02_seq_tools.ipynb 3
# standard libs
import os
import sys
import re

# Common to template
# add into settings.ini, requirements, package name is python-dotenv, for conda build ensure `conda config --add channels conda-forge`
import dotenv  # for loading config from .env files, https://pypi.org/project/python-dotenv/
import envyaml  # Allows to loads env vars into a yaml file, https://github.com/thesimj/envyaml
import fastcore  # To add functionality related to nbdev development, https://github.com/fastai/fastcore/
from fastcore import (
    test,
)
from fastcore.script import (
    call_parse,
)  # for @call_parse, https://fastcore.fast.ai/script
import json  # for nicely printing json and yaml

# import functions from core module (optional, but most likely needed).
from . import core

# Project specific libraries
